#ifndef FFMSETTINGSDIALOG_H
#define FFMSETTINGSDIALOG_H


#include "ui_ffmsettingsdialog.h"

#include <QDialog>

class FFMWidget;

class FFMSettingsDialog : public QDialog
{
    Q_OBJECT
public:
    FFMSettingsDialog(FFMWidget * widget);

    void updateUi();

    bool getBoostCheckBoxState();
    uint getPreset1SpinBoxValue();
    uint getPreset2SpinBoxValue();

private:
    FFMWidget * mWidget;
    Ui::FFMSettingsDialog ui;
};

#endif // FFMSETTINGSDIALOG_H
